@@ -45,17 +45,21 @@ ToPy::ToPy() {
 	import(HdlTypeSubtypeCls, "HdlTypeSubtype");
 	import(HdlClassTypeEnum, "HdlClassType");
 	import(HdlClassDefCls, "HdlClassDef");
+	import(HdlPhysicalDefCls, "HdlPhysicalDef");
 	import(HdlEnumDefCls, "HdlEnumDef");
 	import(HdlStmIfCls, "HdlStmIf");
 	import(HdlStmAssignCls, "HdlStmAssign");
+	import(HdlStmProcessTriggerConstrainEnum, "HdlStmProcessTriggerConstrain");
 	import(HdlStmProcessCls, "HdlStmProcess");
+	import(HdlStmCaseUniqConstrainEnum, "HdlStmCaseUniqConstrain");
 	import(HdlStmCaseTypeEnum, "HdlStmCaseType");
 	import(HdlStmCaseCls, "HdlStmCase");
 	import(HdlStmForCls, "HdlStmFor");
 	import(HdlStmForInCls, "HdlStmForIn");
 	import(HdlStmWhileCls, "HdlStmWhile");
-	import(HdlStmReturnCls, "HdlStmReturn");
+	import(HdlStmNopCls, "HdlStmNop");
 	import(HdlStmRepeatCls, "HdlStmRepeat");
+	import(HdlStmReturnCls, "HdlStmReturn");
 	import(HdlStmBreakCls, "HdlStmBreak");
 	import(HdlStmContinueCls, "HdlStmContinue");
 	import(HdlStmWaitCls, "HdlStmWait");
@@ -302,7 +306,10 @@ PyObject* ToPy::toPy(const HdlOp *o) {
 		return nullptr;
 	}
 
-	return PyObject_CallFunctionObjArgs(HdlOpCls, fn, ops, NULL);
+	auto res = PyObject_CallFunctionObjArgs(HdlOpCls, fn, ops, NULL);
+	Py_DECREF(fn);
+	Py_DECREF(ops);
+	return res;
 }
 
 // [TODO] too similar with the code for HdlModuleDef
@@ -323,9 +330,9 @@ PyObject* ToPy::toPy(const HdlValueIdspace *o) {
 
 	if (PyObject_SetAttrString(py_inst, "declaration_only", dec_only)) {
 		Py_DECREF(py_inst);
-		Py_DECREF(dec_only);
 		return nullptr;
 	}
+	Py_DECREF(dec_only);
 
 	return py_inst;
 }
@@ -349,6 +356,8 @@ PyObject* ToPy::toPy(const HdlIdDef *o) {
 		return nullptr;
 	if (toPy_property(py_inst, "is_static", o->is_static))
 		return nullptr;
+	if (toPy_property(py_inst, "is_shared", o->is_shared))
+		return nullptr;
 	if (toPy_property(py_inst, "direction", o->direction))
 		return nullptr;
 	return py_inst;
@@ -383,16 +392,20 @@ ToPy::~ToPy() {
 	Py_XDECREF(HdlStmBreakCls);
 	Py_XDECREF(HdlStmReturnCls);
 	Py_XDECREF(HdlStmRepeatCls);
+	Py_XDECREF(HdlStmNopCls);
 	Py_XDECREF(HdlStmWhileCls);
 	Py_XDECREF(HdlStmForCls);
 	Py_XDECREF(HdlStmForInCls);
 	Py_XDECREF(HdlStmCaseCls);
 	Py_XDECREF(HdlStmCaseTypeEnum);
+	Py_XDECREF(HdlStmCaseUniqConstrainEnum);
 	Py_XDECREF(HdlStmProcessCls);
+	Py_XDECREF(HdlStmProcessTriggerConstrainEnum);
 	Py_XDECREF(HdlStmAssignCls);
 	Py_XDECREF(HdlStmIfCls);
 	Py_XDECREF(HdlOthersCls);
 	Py_XDECREF(HdlAllCls);
+	Py_XDECREF(HdlPhysicalDefCls);
 	Py_XDECREF(HdlEnumDefCls);
 	Py_XDECREF(HdlClassDefCls);
 	Py_XDECREF(HdlClassTypeEnum);
