@@ -50,22 +50,45 @@ PyObject* ToPy::toPy(const HdlStmBlock *o) {
 	}
 	int e = PyObject_SetAttrString(py_inst, "join_t", join_t);
 	if (e) {
-		Py_DECREF(join_t);
 		Py_DECREF(py_inst);
 		return nullptr;
 	}
+	Py_DECREF(join_t);
 
 	if (toPy_arr(py_inst, "body", o->statements))
 		return nullptr;
 
 	return py_inst;
 }
+PyObject* ToPy::toPy(const HdlStmCaseUniqConstrain o) {
+	const char * name = nullptr;
 
+	switch(o) {
+	case HdlStmCaseUniqConstrain::CASE_UNIQ_PRIORITY:
+		name = "PRIORITY";
+		break;
+	case HdlStmCaseUniqConstrain::CASE_UNIQ_UNIQUE:
+		name = "UNIQUE";
+		break;
+	case HdlStmCaseUniqConstrain::CASE_UNIQ_UNIQUE0:
+		name = "UNIQUE0";
+		break;
+	default:
+		PyErr_SetString(PyExc_ValueError, "Invalid value of HdlStmCaseUniqConstrain");
+		return nullptr;
+	}
+
+	return PyObject_GetAttrString(HdlStmCaseUniqConstrainEnum, name);
+}
 PyObject* ToPy::toPy(const HdlStmCase *o) {
 	auto py_inst = PyObject_CallObject(HdlStmCaseCls, NULL);
 	if (!py_inst) {
 		return nullptr;
 	}
+	if (o->uniq_constrain != HdlStmCaseUniqConstrain::CASE_UNIQ_NONE) {
+		if (toPy_property(py_inst, "uniq_constrain", o->uniq_constrain))
+			return nullptr;
+	}
 	if (toPy_property(py_inst, "type", o->type))
 		return nullptr;
 	if (toPy_property(py_inst, "switch_on", o->select_on))
@@ -175,9 +198,14 @@ PyObject* ToPy::toPy(const HdlStmAssign *o) {
 		if (!py_inst) {
 			break;
 		}
+		Py_DECREF(src);
+		Py_DECREF(dst);
+		Py_XDECREF(time_delay);
+		Py_XDECREF(event_delay);
 		auto _o = dynamic_cast<const HdlStmAssign*>(o);
-		e = PyObject_SetAttrString(py_inst, "is_blocking",
-				PyBool_FromLong((long) _o->is_blocking));
+		auto _is_blocking = PyBool_FromLong((long) _o->is_blocking);
+		e = PyObject_SetAttrString(py_inst, "is_blocking", _is_blocking);
+		Py_DECREF(_is_blocking);
 
 	} while (0);
 	if (e || !py_inst) {
@@ -202,13 +230,35 @@ PyObject* ToPy::toPy(const HdlStmWhile *o) {
 		return nullptr;
 	return py_inst;
 }
+PyObject* ToPy::toPy(const HdlStmProcessTriggerConstrain o) {
+	const char * name = nullptr;
 
+	switch(o) {
+	case HdlStmProcessTriggerConstrain::ALWAYS_FF:
+		name = "FF";
+		break;
+	case HdlStmProcessTriggerConstrain::ALWAYS_COMB:
+		name = "COMB";
+		break;
+	case HdlStmProcessTriggerConstrain::ALWAYS_LATCH:
+		name = "LATCH";
+		break;
+	default:
+		PyErr_SetString(PyExc_ValueError, "Invalid value of HdlStmProcessTriggerConstrain");
+		return nullptr;
+	}
+
+	return PyObject_GetAttrString(HdlStmProcessTriggerConstrainEnum, name);
+}
 PyObject* ToPy::toPy(const HdlStmProcess *o) {
 	auto py_inst = PyObject_CallObject(HdlStmProcessCls, NULL);
 	if (!py_inst) {
 		return nullptr;
 	}
-
+	if (o->trigger_constrain != HdlStmProcessTriggerConstrain::ALWAYS_NONE) {
+		if (toPy_property(py_inst, "trigger_constrain", o->trigger_constrain))
+			return nullptr;
+	}
 	if (o->sensitivity_list) {
 		auto sl = PyList_New(0);
 		if (!sl) {
@@ -217,9 +267,9 @@ PyObject* ToPy::toPy(const HdlStmProcess *o) {
 		}
 		if (PyObject_SetAttrString(py_inst, "sensitivity", sl)) {
 			Py_DECREF(py_inst);
-			Py_DECREF(sl);
 			return nullptr;
 		}
+		Py_DECREF(sl);
 
 		if (toPy_arr(sl, *o->sensitivity_list.get())) {
 			Py_DECREF(py_inst);
@@ -238,6 +288,7 @@ PyObject* ToPy::toPy(const HdlStmImport *o) {
 	}
 
 	auto py_inst = PyObject_CallFunctionObjArgs(HdlImportCls, p, NULL);
+	Py_DECREF(p);
 	if (!py_inst) {
 		Py_DECREF(p);
 		return nullptr;
@@ -256,6 +307,14 @@ PyObject* ToPy::toPy(const HdlStmWait *o) {
 	return py_inst;
 }
 
+PyObject* ToPy::toPy(const HdlStmNop *o) {
+	auto py_inst = PyObject_CallObject(HdlStmNopCls, NULL);
+	if (!py_inst) {
+		return nullptr;
+	}
+	return py_inst;
+}
+
 PyObject* ToPy::toPy(const HdlStmRepeat *o) {
 	auto py_inst = PyObject_CallObject(HdlStmRepeatCls, NULL);
 	if (!py_inst) {
@@ -278,8 +337,8 @@ PyObject* ToPy::toPy(const iHdlStatement *o) {
 		}
 		auto n = dynamic_cast<const HdlStmNop*>(o);
 		if (n) {
-			// @attention currently ignoring labels, doc etc
-			Py_RETURN_NONE;
+			py_inst = toPy(n);
+			break;
 		}
 		auto b = dynamic_cast<const HdlStmBlock*>(o);
 		if (b) {
@@ -356,6 +415,7 @@ PyObject* ToPy::toPy(const iHdlStatement *o) {
 		PyErr_SetString(PyExc_TypeError, err_msg.c_str());
 		return nullptr;
 	} while (0);
+
 	if (!py_inst)
 		return nullptr;
 
@@ -368,6 +428,9 @@ PyObject* ToPy::toPy(const iHdlStatement *o) {
 	if (toPy_property(py_inst, "in_preproc", o->in_preproc))
 		return nullptr;
 
+	if (toPy(static_cast<const WithPos*>(o), py_inst))
+		return nullptr;
+
 	return py_inst;
 }
 
