@@ -10,6 +10,10 @@ enum HdlStmCaseType {
 	CASE, CASEZ, CASEX,
 };
 
+enum HdlStmCaseUniqConstrain {
+    CASE_UNIQ_NONE, CASE_UNIQ_UNIQUE, CASE_UNIQ_UNIQUE0, CASE_UNIQ_PRIORITY
+};
+
 const char * HdlStmCaseType_toString(HdlStmCaseType o);
 
 /*
@@ -17,6 +21,7 @@ const char * HdlStmCaseType_toString(HdlStmCaseType o);
  * */
 class HdlStmCase: public iHdlStatement {
 public:
+	HdlStmCaseUniqConstrain uniq_constrain;
 	HdlStmCaseType type;
 	std::unique_ptr<iHdlExprItem> select_on;
 	std::vector<HdlExprAndiHdlObj> cases;
