@@ -1,19 +1,18 @@
 #pragma once
 
 #include <hdlConvertor/svConvertor/sv2017Parser/sv2017Parser.h>
-#include <hdlConvertor/svConvertor/commentParser.h>
+#include <hdlConvertor/svConvertor/baseSvParser.h>
 #include <hdlConvertor/hdlAst/iHdlExpr.h>
 
 namespace hdlConvertor {
 namespace sv {
 
-class VerDelayParser {
-	SVCommentParser &commentParser;
+class VerDelayParser: public BaseSvParser {
 public:
+	using BaseSvParser::BaseSvParser;
 	using sv2017Parser = sv2017_antlr::sv2017Parser;
 	using HdlEventList = std::unique_ptr<std::vector<std::unique_ptr<hdlAst::iHdlExprItem>>>;
 
-	VerDelayParser(SVCommentParser &commentParser);
 	std::unique_ptr<hdlAst::iHdlExprItem> visitDelay_control(
 			sv2017Parser::Delay_controlContext *ctx);
 	// @returns <delay, events>
