@@ -10,20 +10,16 @@
 #include <hdlConvertor/hdlAst/hdlStmCase.h>
 #include <hdlConvertor/hdlAst/hdlModuleDec.h>
 #include <hdlConvertor/vhdlConvertor/commentParser.h>
+#include <hdlConvertor/vhdlConvertor/baseVhdlParser.h>
 
 namespace hdlConvertor {
 namespace vhdl {
 
-class VhdlGenerateStatementParser {
-	VhdlCommentParser &commentParser;
+class VhdlGenerateStatementParser: public BaseVhdlParser {
 public:
+	using BaseVhdlParser::BaseVhdlParser;
 	using vhdlParser = vhdl_antlr::vhdlParser;
 
-	bool hierarchyOnly;
-
-	VhdlGenerateStatementParser(VhdlCommentParser &_commentParser,
-			bool _hierarchyOnly);
-
 	std::unique_ptr<hdlAst::iHdlStatement> visitGenerate_statement(
 			vhdlParser::Generate_statementContext *ctx);
 	std::unique_ptr<hdlAst::iHdlStatement> visitFor_generate_statement(
@@ -34,8 +30,6 @@ public:
 			vhdlParser::Case_generate_statementContext *ctx);
 	template<typename CTX_T>
 	std::unique_ptr<hdlAst::iHdlObj> visitGenerate_statement_body(CTX_T *ctx);
-	static hdlAst::HdlModuleDec* visitComponent_declaration(
-			vhdlParser::Component_declarationContext *ctx);
 };
 
 }
