@@ -5,36 +5,21 @@
 namespace hdlConvertor {
 namespace hdlAst {
 
-static const char* const opTypeToStr[HdlOpType::ARITH_SHIFT_RIGHT_ASSIGN + 1] = {
-		"RANGE",
-		"THROUGHOUT",
-		"REFERENCE",
-		"DEREFERENCE",
-		"DEFINE_RESOLVER",
-		"TYPE_OF",
-		"INDEX",
-		"PART_SELECT_POST",
-		"PART_SELECT_PRE",
-		"DOWNTO",
-		"TO",
+static const char* const opTypeToStr[HdlOpType::UNIT_SPEC + 1] = {
 		"MINUS_UNARY",
 		"PLUS_UNARY",
-		"OR_UNARY",
-		"AND_UNARY",
-		"NAND_UNARY",
-		"NOR_UNARY",
-		"XOR_UNARY",
-		"XNOR_UNARY",
 		"SUB",
 		"ADD",
 		"DIV",
 		"MUL",
 		"MOD",
 		"REM",
-		"CONCAT",
-		"REPL_CONCAT",
 		"POW",
 		"ABS",
+		"INCR_PRE",
+		"DECR_PRE",
+		"INCR_POST",
+		"DECR_POST",
 		"NEG_LOG",
 		"NEG",
 		"AND_LOG",
@@ -45,6 +30,18 @@ static const char* const opTypeToStr[HdlOpType::ARITH_SHIFT_RIGHT_ASSIGN + 1] =
 		"NOR",
 		"XOR",
 		"XNOR",
+		"OR_UNARY",
+		"AND_UNARY",
+		"NAND_UNARY",
+		"NOR_UNARY",
+		"XOR_UNARY",
+		"XNOR_UNARY",
+		"SLL",
+		"SRL",
+		"SLA",
+		"SRA",
+		"ROL",
+		"ROR",
 		"EQ",
 		"NE",
 		"IS",
@@ -53,45 +50,49 @@ static const char* const opTypeToStr[HdlOpType::ARITH_SHIFT_RIGHT_ASSIGN + 1] =
 		"LE",
 		"GT",
 		"GE",
-		"SLL",
-		"SRL",
-		"SLA",
-		"SRA",
-		"ROL",
-		"ROR",
-		"TERNARY",
-		"DOT",
-		"DOUBLE_COLON",
-		"APOSTROPHE",
-		"CALL",
-		"PARAMETRIZATION",
-		"ARROW",
-		"RISING",
-		"FALLING",
-		"MAP_ASSOCIATION",
 		"EQ_MATCH",
 		"NE_MATCH",
 		"LT_MATCH",
 		"LE_MATCH",
 		"GT_MATCH",
 		"GE_MATCH",
-		"INCR_PRE",
-		"DECR_PRE",
-		"INCR_POST",
-		"DECR_POST",
-	    "ASSIGN",
-	    "PLUS_ASSIGN",
-	    "MINUS_ASSIGN",
-	    "MUL_ASSIGN",
-	    "DIV_ASSIGN",
-	    "MOD_ASSIGN",
-	    "AND_ASSIGN",
-	    "OR_ASSIGN",
-	    "XOR_ASSIGN",
-	    "SHIFT_LEFT_ASSIGN",
-	    "SHIFT_RIGHT_ASSIGN",
-	    "ARITH_SHIFT_LEFT_ASSIGN",
-	    "ARITH_SHIFT_RIGHT_ASSIGN",
+		"INDEX",
+		"CONCAT",
+		"REPL_CONCAT",
+		"PART_SELECT_POST",
+		"PART_SELECT_PRE",
+		"DOT",
+		"DOUBLE_COLON",
+		"APOSTROPHE",
+		"ARROW",
+		"REFERENCE",
+		"DEREFERENCE",
+		"ASSIGN",
+		"PLUS_ASSIGN",
+		"MINUS_ASSIGN",
+		"MUL_ASSIGN",
+		"DIV_ASSIGN",
+		"MOD_ASSIGN",
+		"AND_ASSIGN",
+		"OR_ASSIGN",
+		"XOR_ASSIGN",
+		"SHIFT_LEFT_ASSIGN",
+		"SHIFT_RIGHT_ASSIGN",
+		"ARITH_SHIFT_LEFT_ASSIGN",
+		"ARITH_SHIFT_RIGHT_ASSIGN",
+		"TERNARY",
+		"CALL",
+		"RISING",
+		"FALLING",
+		"DOWNTO",
+		"TO",
+		"PARAMETRIZATION",
+		"MAP_ASSOCIATION",
+		"RANGE",
+		"THROUGHOUT",
+		"DEFINE_RESOLVER",
+		"TYPE_OF",
+		"UNIT_SPEC",
 };
 
 
@@ -119,8 +120,8 @@ HdlOpType HdlOpType_toUnary(HdlOpType o) {
 }
 
 const char* HdlOpType_toString(HdlOpType opt) {
-	if (opt > HdlOpType::ARITH_SHIFT_RIGHT_ASSIGN)
-		throw std::runtime_error("Invalid operator type");
+	if (opt > HdlOpType::UNIT_SPEC)
+		throw std::range_error("Invalid operator type");
 	return opTypeToStr[opt];
 }
 
