@@ -3,24 +3,26 @@
 
 #include <hdlConvertor/createObject.h>
 
-using namespace std;
-
 namespace hdlConvertor {
 namespace hdlAst {
 
+using namespace std;
+
 HdlStmProcess::HdlStmProcess() :
-		iHdlStatement(), body(create_object<HdlStmBlock>(nullptr)) {
+		iHdlStatement(), trigger_constrain(HdlStmProcessTriggerConstrain::ALWAYS_NONE), body(
+				create_object<HdlStmBlock>(nullptr)) {
 }
 
 HdlStmProcess::HdlStmProcess(
 		unique_ptr<vector<unique_ptr<iHdlExprItem>>> _sensitivity) :
-		iHdlStatement(), sensitivity_list(move(_sensitivity)), body(
-				create_object<HdlStmBlock>(nullptr)) {
+		iHdlStatement(), trigger_constrain(HdlStmProcessTriggerConstrain::ALWAYS_NONE), sensitivity_list(
+				move(_sensitivity)), body(create_object<HdlStmBlock>(nullptr)) {
 }
 HdlStmProcess::HdlStmProcess(
 		unique_ptr<vector<unique_ptr<iHdlExprItem>>> _sensitivity,
 		unique_ptr<iHdlStatement> _body) :
-		iHdlStatement(), sensitivity_list(move(_sensitivity)), body(move(_body)) {
+		iHdlStatement(), trigger_constrain(HdlStmProcessTriggerConstrain::ALWAYS_NONE), sensitivity_list(
+				move(_sensitivity)), body(move(_body)) {
 }
 
 HdlStmProcess::~HdlStmProcess() {
