@@ -10,16 +10,13 @@
 #include <hdlConvertor/svConvertor/exprPrimaryParser.h>
 #include <hdlConvertor/svConvertor/typeParser.h>
 
-using namespace std;
-using sv2017Parser = sv2017_antlr::sv2017Parser;
-using namespace hdlConvertor::hdlAst;
 
 namespace hdlConvertor {
 namespace sv {
 
-VerExprParser::VerExprParser(SVCommentParser &_commentParser) :
-		commentParser(_commentParser) {
-}
+using namespace std;
+using namespace hdlConvertor::hdlAst;
+
 
 unique_ptr<iHdlExprItem> VerExprParser::visitConstant_expression(
 		sv2017Parser::Constant_expressionContext *ctx) {
@@ -194,7 +191,7 @@ unique_ptr<iHdlExprItem> VerExprParser::visitExpression(
 
 	auto _p = ctx->primary();
 	if (_p) {
-		VerExprPrimaryParser pp(commentParser);
+		VerExprPrimaryParser pp(this);
 		auto p = pp.visitPrimary(_p);
 		auto _uo = ctx->unary_operator();
 		if (_uo) {
@@ -499,19 +496,26 @@ unique_ptr<iHdlExprItem> VerExprParser::visitPackage_or_class_scoped_hier_id_wit
 	for (auto bs : ctx->bit_select()) {
 		res = visitBit_select(bs, move(res));
 	}
-	// "Vector bit-select and part-select addressing"
-	if (ctx->operator_plus_minus()) {
-		NotImplementedLogger::print(
-				"VerExprParser.visitPackage_or_class_scoped_hier_id_with_select - operator_plus_minus",
-				ctx);
-	}
+
 	auto exprs = ctx->expression();
 	if (exprs.size()) {
 		assert(exprs.size() == 2);
 		auto e0 = visitExpression(exprs[0]);
 		auto e1 = visitExpression(exprs[1]);
-		auto sel = create_object<HdlOp>(ctx, move(e0), HdlOpType::DOWNTO,
-				move(e1));
+		auto _pm = ctx->operator_plus_minus();
+		HdlOpType op = HdlOpType::DOWNTO;
+		if (_pm) {
+			// e0 is offset
+			// e1 is width
+			// pm specifies direction of slice from offset
+			auto pm = VerLiteralParser::visitOperator_plus_minus(_pm);
+			if (pm == HdlOpType::ADD) {
+				op = HdlOpType::PART_SELECT_POST;
+			} else {
+				op = HdlOpType::PART_SELECT_PRE;
+			}
+		}
+		auto sel = create_object<HdlOp>(ctx, move(e0), op, move(e1));
 		return append_expr(ctx, move(res), HdlOpType::INDEX, move(sel));
 	}
 	return res;
@@ -523,7 +527,7 @@ std::vector<unique_ptr<iHdlExprItem>> VerExprParser::visitParameter_value_assign
 	//   HASH LPAREN ( list_of_parameter_value_assignments )? RPAREN;
 	auto lpa = ctx->list_of_parameter_value_assignments();
 	if (lpa) {
-		VerModuleInstanceParser mip(commentParser);
+		VerModuleInstanceParser mip(this);
 		return mip.visitList_of_parameter_value_assignments(lpa);
 	} else {
 		return {};
@@ -650,7 +654,7 @@ void VerExprParser::visitList_of_arguments(
 	//      | ( COMMA ( expression )? )+
 	//     )
 	//     ( COMMA list_of_arguments_named_item )*;
-	VerExprParser ep(commentParser);
+	VerExprParser ep(this);
 	bool expecting_value = true;
 	for (auto c : ctx->children) {
 		auto t = dynamic_cast<antlr4::tree::TerminalNode*>(c);
