@@ -18,19 +18,14 @@
 #include <hdlConvertor/vhdlConvertor/subProgramDeclarationParser.h>
 #include <hdlConvertor/vhdlConvertor/subProgramParser.h>
 #include <hdlConvertor/vhdlConvertor/variableParser.h>
+#include <assert.h>
 
 namespace hdlConvertor {
 namespace vhdl {
 
 using namespace hdlConvertor::hdlAst;
-using vhdlParser = vhdl_antlr::vhdlParser;
 using namespace std;
 
-VhdlGenerateStatementParser::VhdlGenerateStatementParser(
-		VhdlCommentParser &_commentParser, bool _hierarchyOnly) :
-		commentParser(_commentParser), hierarchyOnly(_hierarchyOnly) {
-}
-
 std::unique_ptr<iHdlStatement> VhdlGenerateStatementParser::visitGenerate_statement(
 		vhdlParser::Generate_statementContext *ctx) {
 	//generate_statement
@@ -63,8 +58,8 @@ std::unique_ptr<iHdlStatement> VhdlGenerateStatementParser::visitFor_generate_st
 	//           END GENERATE ( label )? SEMI
 	// ;
 
-	auto args = VhdlStatementParser::visitParameter_specification(
-			ctx->parameter_specification());
+	VhdlStatementParser sp(commentParser, hierarchyOnly);
+	auto args = sp.visitParameter_specification(ctx->parameter_specification());
 	auto objs = visitGenerate_statement_body(ctx->generate_statement_body());
 	auto fstm = create_object<HdlStmForIn>(ctx, move(args.first),
 			move(args.second), move(objs));
@@ -115,6 +110,7 @@ std::unique_ptr<HdlStmIf> VhdlGenerateStatementParser::visitIf_generate_statemen
 
 	ifStm = create_object<HdlStmIf>(ctx, move(cond), move(ifTrue), elseIfs,
 			move(ifFalse));
+	ifStm->in_preproc = true;
 	auto labels = ctx->label();
 	if (labels.size()) {
 		ifStm->labels.push_back(VhdlLiteralParser::visitLabel(labels[0]));
@@ -201,31 +197,11 @@ std::unique_ptr<hdlAst::iHdlObj> VhdlGenerateStatementParser::visitGenerate_stat
 }
 
 template std::unique_ptr<hdlAst::iHdlObj> VhdlGenerateStatementParser::visitGenerate_statement_body<
-		vhdlParser::Generate_statement_bodyContext>(
-		vhdlParser::Generate_statement_bodyContext *ctx);
+		vhdl_antlr::vhdlParser::Generate_statement_bodyContext>(
+		vhdl_antlr::vhdlParser::Generate_statement_bodyContext *ctx);
 template std::unique_ptr<hdlAst::iHdlObj> VhdlGenerateStatementParser::visitGenerate_statement_body<
-		vhdlParser::Generate_statement_body_with_begin_endContext>(
-		vhdlParser::Generate_statement_body_with_begin_endContext *ctx);
-
-HdlModuleDec* VhdlGenerateStatementParser::visitComponent_declaration(
-		vhdlParser::Component_declarationContext *ctx) {
-	// component_declaration:
-	//       COMPONENT identifier ( IS )?
-	//           ( generic_clause )?
-	//           ( port_clause )?
-	//       END COMPONENT ( identifier )? SEMI
-	// ;
-	HdlModuleDec *e = new HdlModuleDec();
-	e->name = ctx->identifier(0)->getText();
-	auto gc = ctx->generic_clause();
-	if (gc)
-		VhdlEntityParser::visitGeneric_clause(gc, e->generics);
-	auto pc = ctx->port_clause();
-	if (pc)
-		VhdlEntityParser::visitPort_clause(pc, e->ports);
-
-	return e;
-}
+		vhdl_antlr::vhdlParser::Generate_statement_body_with_begin_endContext>(
+		vhdl_antlr::vhdlParser::Generate_statement_body_with_begin_endContext *ctx);
 
 }
 }
